
/**
 * ISOAK - Iterative similarity optimal assignment kernel.
 * 
 * Written by Matthias Rupp 2006-2007.
 * Copyright (c) 2006-2007, Matthias Rupp, Ewgenij Proschak, Gisbert Schneider.
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 *  * The above copyright notice, this permission notice and the following disclaimers
 *    shall be included in all copies or substantial portions of this software.
 *  * The names of the authors may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * 
 * Please cite
 * 
 * Matthias Rupp, Ewgenij Proschak, Gisbert Schneider:
 * A Kernel Approach to Molecular Similarity Based on Iterative Graph Similarity,
 * Journal of Chemical Information and Molecular Modeling, 47(6): 2280-2286, 2007, 
 * DOI http://dx.doi.org/10.1021/ci700274r.
 *
 * if you use this software.
 */

package info.mrupp.isoak1;

/**
 * Periodic table of the elements.
 * 
 * Elements with temporary names (three letter abbreviations) are not included.
 */

public enum Element {
	H	(  1, "H" , "Hydrogen"     ),
    He	(  2, "He", "Helium"       ),
    Li	(  3, "Li", "Lithium"      ),
    Be	(  4, "Be", "Beryllium"    ),
	B	(  5, "B" , "Boron"        ),
	C	(  6, "C" , "Carbon"       ),
	N	(  7, "N" , "Nitrogen"     ),
	O	(  8, "O" , "Oxygen"       ),
	F	(  9, "F" , "Fluorine"     ),
	Ne	( 10, "Ne", "Neon"         ),
    Na	( 11, "Na", "Sodium"       ),
    Mg	( 12, "Mg", "Magnesium"    ),
    Al	( 13, "Al", "Aluminimum"   ),
    Si	( 14, "Si", "Silicon"      ),
    P	( 15, "P" , "Phosphorus"   ),
    S	( 16, "S" , "Sulfur"       ),
    Cl	( 17, "Cl", "Chlorine"     ),
    Ar	( 18, "Ar", "Argon"        ),
    K	( 19, "K" , "Potassium"    ),
    Ca	( 20, "Ca", "Calcium"      ),
    Sc	( 21, "Sc", "Scandium"     ),
    Ti	( 22, "Ti", "Titanium"     ),
    V	( 23, "V" , "Vanadium"     ),
    Cr	( 24, "Cr", "Chromium"     ),
    Mn	( 25, "Mn", "Manganese"    ),
    Fe	( 26, "Fe", "Iron"         ),
    Co	( 27, "Co", "Cobalt"       ),
    Ni	( 28, "Ni", "Nickel"       ),
    Cu	( 29, "Cu", "Copper"       ),
    Zn	( 30, "Zn", "Zinc"         ),
    Ga	( 31, "Ga", "Gallium"      ),
    Ge	( 32, "Ge", "Germanium"    ),
    As	( 33, "As", "Arsenic"      ),
    Se	( 34, "Se", "Selenium"     ),
    Br	( 35, "Br", "Bromine"      ),
    Kr	( 36, "Kr", "Krypton"      ),
    Rb	( 37, "Rb", "Rubidium"     ),
    Sr	( 38, "Sr", "Strontium"    ),
    Y	( 39, "Y" , "Yttrium"      ),
    Zr	( 40, "Zr", "Zirconium"    ),
    Nb	( 41, "Nb", "Niobium"      ),
    Mo	( 42, "Mo", "Molybdenum"   ),
    Tc	( 43, "Tc", "Technetium"   ),
    Ru	( 44, "Ru", "Ruthenium"    ),
    Rh	( 45, "Rh", "Rhodium"      ),
    Pd	( 46, "Pd", "Palladium"    ),
    Ag	( 47, "Ag", "Silver"       ),
    Cd	( 48, "Cd", "Cadmium"      ),
    In	( 49, "In", "Indium"       ),
    Sn	( 50, "Sn", "Tin"          ),
    Sb	( 51, "Sb", "Antimony"     ),
    Te	( 52, "Te", "Tellurium"    ),
    I	( 53, "I" , "Iodine"       ),
    Xe	( 54, "Xe", "Xenon"        ),
    Cs	( 55, "Cs", "Cesium"       ),
    Ba	( 56, "Ba", "Barium"       ),
    La	( 57, "La", "Lanthanum"    ),
    Ce	( 58, "Ce", "Cerium"       ),
    Pr	( 59, "Pr", "Praseodymium" ),
    Nd	( 60, "Nd", "Neodymium"    ),
    Pm	( 61, "Pm", "Promethium"   ),
    Sm	( 62, "Sm", "Samarium"     ),
    Eu	( 63, "Eu", "Europium"     ),
    Gd	( 64, "Gd", "Gadolinium"   ),
    Tb	( 65, "Tb", "Terbium"      ),
    Dy	( 66, "Dy", "Dysprosium"   ),
    Ho	( 67, "Ho", "Holmium"      ),
    Er	( 68, "Er", "Erbium"       ),
    Tm	( 69, "Tm", "Thulium"      ),
    Yb	( 70, "Yb", "Ytterbium"    ),
    Lu	( 71, "Lu", "Lutetium"     ),
    Hf	( 72, "Hf", "Hafnium"      ),
    Ta	( 73, "Ta", "Tantalum"     ),
    W	( 74, "W" , "Tungsten"     ),
    Re	( 75, "Re", "Rhenium"      ),
    Os	( 76, "Os", "Osmium"       ),
    Ir	( 77, "Ir", "Iridium"      ),
    Pt	( 78, "Pt", "Platinum"     ),
    Au	( 79, "Au", "Gold"         ),
    Hg	( 80, "Hg", "Mercury"      ),
    Tl	( 81, "Tl", "Thalium"      ),
    Pb	( 82, "Pb", "Lead"         ),
    Bi	( 83, "Bi", "Bismuth"      ),
    Po	( 84, "Po", "Polonium"     ),
    At	( 85, "At", "Astatine"     ),
    Rn	( 86, "Rn", "Radon"        ),
    Fr	( 87, "Fr", "Francium"     ), 
    Ra	( 88, "Ra", "Radium"       ),
    Ac	( 89, "Ac", "Actinium"     ),
    Th	( 90, "Th", "Thorium"      ),
    Pa	( 91, "Pa", "Protactinium" ),
    U	( 92, "U" , "Uranium"      ),
    Np	( 93, "Np", "Neptunium"    ),
    Pu  ( 94, "Pu", "Plutonium"    ),
    Am	( 95, "Am", "Americium"    ),
    Cm	( 96, "Cm", "Curium"       ),
    Bk	( 97, "Bk", "Berkelium"    ),
    Cf	( 98, "Cf", "Californium"  ),
    Es	( 99, "Es", "Einsteinium"  ),
    Fm	(100, "Fm", "Fermium"      ),
    Md	(101, "Md", "Mendelevium"  ),
    No	(102, "No", "Nobelium"     ),
    Lr	(103, "Lr", "Lawrencium"   ),
    Rf	(104, "Rf", "Rutherfordium"),
    Db	(105, "Db", "Dubnium"      ),
    Sg	(106, "Sg", "Seaborgium"   ),
    Bh	(107, "Bh", "Bohrium"      ),
    Hs	(108, "Hs", "Hassium"      ),
    Mt	(109, "Mt", "Meitnerium"   ),
    Ds	(110, "Ds", "Darmstadtium" ),
    Rg	(111, "Rg", "Roentgenium"  );
	
    /** Atomic number ("Ordnungszahl"), the number of protons. */
	public int atomicNumber() { return atomicNumber; }
    
    /** The two-character abbreviation of the element.*/
	public String abbrev() { return abbrev; }
	
    /** The unabbreviated english name of the element. */
    public String fullName() { return fullName; }

    /** Returns the element constant for a one or two letter abbreviation.
     * 
     * @param abbrev one or two letter abbreviation of an element.
     * @return the element constant for the given abbreviation.
     */
	public static Element fromString(String abbrev) {
		abbrev = abbrev.trim();
		for (Element element : Element.values()) if (element.abbrev().equals(abbrev)) return element;
		throw new IllegalArgumentException(String.format("Unknown element abbreviation '%s' encountered in construction of Element from String.", abbrev));
	}

	private final int atomicNumber;
	private final String abbrev; 
	private final String fullName;
	
	Element(int atomicNumber, String abbrev, String fullName) { this.atomicNumber = atomicNumber; this.abbrev = abbrev; this.fullName = fullName; }
}
